@@ -50,6 +50,14 @@ SUCH DAMAGE.
 #define __need_size_t
 #define __need_wint_t
 #include <stddef.h>
+
+/* The Arm Compiler doesn't define wint_t as part of stddef.h so
+ * define it here.
+ */
+#if defined (__ARMCC_VERSION) && (__ARMCC_VERSION >= 6100100)
+typedef __WINT_TYPE__ wint_t;
+#endif
+
 #include <newlib.h>
 #include <sys/config.h>
 #include <machine/_types.h>
@@ -81,7 +89,7 @@ typedef int __pid_t;
 #endif
 
 #ifndef __machine_dev_t_defined
-#ifdef linux
+#ifdef __linux
 typedef __uint64_t __dev_t;
 #else
 typedef short __dev_t;
@@ -89,14 +97,14 @@ typedef short __dev_t;
 #endif
 
 #ifndef __machine_uid_t_defined
-#ifdef linux
+#ifdef __linux
 typedef __uint32_t __uid_t;
 #else
 typedef unsigned short __uid_t;
 #endif
 #endif
 #ifndef __machine_gid_t_defined
-#ifdef linux
+#ifdef __linux
 typedef __uint32_t __gid_t;
 #else
 typedef unsigned short __gid_t;
@@ -109,7 +117,7 @@ typedef __uint32_t __id_t;
 
 #ifndef __machine_ino_t_defined
 #if (defined(__i386__) && (defined(GO32) || defined(__MSDOS__))) || \
-	defined(__sparc__) || defined(__SPU__) || defined(linux)
+	defined(__sparc__) || defined(__SPU__) || defined(__linux)
 typedef unsigned long __ino_t;
 #else
 typedef unsigned short __ino_t;
@@ -234,6 +242,10 @@ typedef	_TIME_T_	__time_t;
 
 typedef	_CLOCKID_T_	__clockid_t;
 
+#ifndef __machine_daddr_t_defined
+typedef	long		__daddr_t;
+#endif
+
 #define	_TIMER_T_	unsigned long
 typedef	_TIMER_T_	__timer_t;
 
@@ -245,7 +257,7 @@ typedef	__uint8_t	__sa_family_t;
 typedef	__uint32_t	__socklen_t;
 #endif
 
-typedef	int		__nl_item;
+typedef	__int32_t	__nl_item;
 typedef	unsigned short	__nlink_t;
 typedef	long		__suseconds_t;	/* microseconds (signed) */
 typedef	unsigned long	__useconds_t;	/* microseconds (unsigned) */
