@@ -720,7 +720,7 @@ VFPRINTF (
 	uio.uio_resid += (len); \
 	iovp++; \
 	if (++uio.uio_iovcnt >= NIOV) { \
-		if (__SPRINT(data, fp, &uio)) \
+		if (__SPRINT(fp, &uio)) \
 			goto error; \
 		iovp = iov; \
 	} \
@@ -743,7 +743,7 @@ VFPRINTF (
 	PAD((len) - (n > 0 ? n : 0), (with)); \
 }
 #define	FLUSH() { \
-	if (uio.uio_resid && __SPRINT(data, fp, &uio)) \
+	if (uio.uio_resid && __SPRINT(fp, &uio)) \
 		goto error; \
 	uio.uio_iovcnt = 0; \
 	iovp = iov; \
