@@ -1319,6 +1319,20 @@ isdenormf(float f)
     return (u.i & 0x7f800000) == 0;
 }
 
+float
+strtof_l (const char *__restrict s00, char **__restrict se, locale_t loc)
+{
+  double val = strtod_l (s00, se, loc);
+  if (isnan (val))
+    return signbit (val) ? -nanf ("") : nanf ("");
+  float retval = (float) val;
+#ifndef NO_ERRNO
+  if ((isinf (retval) && !isinf (val)) || (isdenormf(retval) && !isdenorm(val)))
+    _REENT_ERRNO(_REENT) = ERANGE;
+#endif
+  return retval;
+}
+
 float
 strtof (const char *__restrict s00,
 	char **__restrict se)
