@@ -162,6 +162,13 @@ e_to_str(int e)
 #define PASTE_LDBL(exp) _PASTE_LDBL(exp)
 
 #define BIG PASTE_LDBL(__LDBL_MAX_EXP__)
+#if __LDBL_MANT_DIG__ >= 64
+#define BIGODD  0x1.123456789abcdef2p+63l
+#define BIGEVEN 0x1.123456789abcdef0p+63l
+#else
+#define BIGODD  0x1.123456789abcdp+52
+#define BIGEVEN 0x1.123456789abccp+52
+#endif
 #define SMALL __LDBL_DENORM_MIN__
 #define FLOAT_T long double
 #define MIN_VAL __LDBL_DENORM_MIN__
@@ -177,6 +184,8 @@ e_to_str(int e)
 #include "math_errhandling_tests.c"
 
 #undef BIG
+#undef BIGODD
+#undef BIGEVEN
 #undef SMALL
 #undef MIN_VAL
 #undef MAX_VAL
@@ -201,6 +210,8 @@ e_to_str(int e)
 #define DOUBLE_EXCEPTION_TEST EXCEPTION_TEST
 
 #define BIG 1.7e308
+#define BIGODD  0x1.123456789abcdp+52
+#define BIGEVEN 0x1.123456789abccp+52
 #define SMALL 5e-324
 #define FLOAT_T double
 #define MIN_VAL __DBL_DENORM_MIN__
@@ -217,6 +228,8 @@ e_to_str(int e)
 #include "math_errhandling_tests.c"
 
 #undef BIG
+#undef BIGODD
+#undef BIGEVEN
 #undef SMALL
 #undef MIN_VAL
 #undef MAX_VAL
@@ -232,6 +245,8 @@ e_to_str(int e)
 /* Tests with floats */
 #define EXCEPTION_TEST	MATH_ERREXCEPT
 #define BIG 3e38
+#define BIGODD  0x1.123456p+23
+#define BIGEVEN 0x1.123454p+23
 #define SMALL 1e-45
 #define MIN_VAL 0x8p-152f
 #define MAX_VAL 0xf.fffffp+124f
